==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/chaos/kotlin/inputs/BranchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.chaos.kotlin.inputs

import com.pulumi.azurenative.chaos.inputs.BranchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Model that represents a branch in the step.
 * @property actions List of actions.
 * @property name String of the branch name.
 */
public data class BranchArgs(
    public val actions: Output<List<Any>>,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.chaos.inputs.BranchArgs> {
    override fun toJava(): com.pulumi.azurenative.chaos.inputs.BranchArgs =
        com.pulumi.azurenative.chaos.inputs.BranchArgs.builder()
            .actions(actions.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BranchArgs].
 */
@PulumiTagMarker
public class BranchArgsBuilder internal constructor() {
    private var actions: Output<List<Any>>? = null

    private var name: Output<String>? = null

    /**
     * @param value List of actions.
     */
    @JvmName("wnqjcrhmlrfejwhy")
    public suspend fun actions(`value`: Output<List<Any>>) {
        this.actions = value
    }

    @JvmName("bhrsusruoknhhgeb")
    public suspend fun actions(vararg values: Output<Any>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values List of actions.
     */
    @JvmName("kdooxupoghjoqgog")
    public suspend fun actions(values: List<Output<Any>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value String of the branch name.
     */
    @JvmName("mmytvnbbvvokvhdc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of actions.
     */
    @JvmName("pxpthfmugbnfkvpw")
    public suspend fun actions(`value`: List<Any>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param values List of actions.
     */
    @JvmName("whyjmywuowhdpakv")
    public suspend fun actions(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value String of the branch name.
     */
    @JvmName("jvbobjdwekgtdwxg")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): BranchArgs = BranchArgs(
        actions = actions ?: throw PulumiNullFieldException("actions"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/chaos/kotlin/inputs/BranchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.chaos.kotlin.inputs

import com.pulumi.azurenative.chaos.inputs.BranchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Model that represents a branch in the step.
 * @property actions List of actions.
 * @property name String of the branch name.
 */
public data class BranchArgs(
    public val actions: Output<List<Any>>,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.chaos.inputs.BranchArgs> {
    override fun toJava(): com.pulumi.azurenative.chaos.inputs.BranchArgs =
        com.pulumi.azurenative.chaos.inputs.BranchArgs.builder()
            .actions(actions.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BranchArgs].
 */
@PulumiTagMarker
public class BranchArgsBuilder internal constructor() {
    private var actions: Output<List<Any>>? = null

    private var name: Output<String>? = null

    /**
     * @param value List of actions.
     */
    @JvmName("truvtvgetvcaxmwy")
    public suspend fun actions(`value`: Output<List<Any>>) {
        this.actions = value
    }

    @JvmName("qmhdpxuwxpmkodng")
    public suspend fun actions(vararg values: Output<Any>) {
        this.actions = Output.all(values.asList())
    }

    /**
     * @param values List of actions.
     */
    @JvmName("uplorsiqiovsitgy")
    public suspend fun actions(values: List<Output<Any>>) {
        this.actions = Output.all(values)
    }

    /**
     * @param value String of the branch name.
     */
    @JvmName("sconvrfolkwmsuuh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of actions.
     */
    @JvmName("ttjjjxeispvosvpw")
    public suspend fun actions(`value`: List<Any>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param values List of actions.
     */
    @JvmName("jwfjlwxiogrcmmkl")
    public suspend fun actions(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param value String of the branch name.
     */
    @JvmName("uqwlwunxxprkqdkr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): BranchArgs = BranchArgs(
        actions = actions ?: throw PulumiNullFieldException("actions"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
